/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2018, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
#include "testingconfiguration.h"

// Run input file generated by CMake spc_and_methanol_tpr target.
const std::string             gmxapi::testing::sample_tprfilename = "${CMAKE_CURRENT_BINARY_DIR}/topol.tpr";

/*! \todo We need to handle tests on both many-CPU nodes and GPU nodes.
 * If we don't set -ntomp to a low number, integration tests on Travis-CI fail
 * with errors about the auto-detected OpenMP thread number being too big. But
 * on a GPU node, such as a GROMACS Jenkins build node, setting `-ntomp` without
 * also setting `-ntmpi` results in an error. However, we don't have a good way
 * of setting `-ntmpi` for gmxapi tests built for thread-MPI and not setting it
 * for those that are not.
 *
 * Removing the following constant should be fine for now,
 * but this will need to be resolved at some point.
 */
const std::vector<std::string> gmxapi::testing::mdArgs {
// Number of OMP threads must be set to a reasonable non-default value to avoid
// failures when testing on large nodes.
//    "-ntomp", "1"
};

// Time step size provided during build configuration through
// internal CMake variable GMXAPI_TEST_TIMESTEP
const double gmxapi::testing::testingTimestep = @GMXAPI_TEST_TIMESTEP@;
